@@ -24,6 +24,7 @@ from xml.etree.cElementTree import parse
 
 from . import ast
 from .girwriter import COMPATIBLE_GIR_VERSION
+from .collections import OrderedDict
 
 CORE_NS = "http://www.gtk.org/introspection/core/1.0"
 C_NS = "http://www.gtk.org/introspection/c/1.0"
@@ -165,9 +166,18 @@ class GIRParser(object):
 
     def _parse_generic_attribs(self, node, obj):
         assert isinstance(obj, ast.Annotated)
+        skip = node.attrib.get('skip')
+        if skip:
+            try:
+                obj.skip = int(skip) > 0
+            except ValueError:
+                obj.skip = False
         introspectable = node.attrib.get('introspectable')
         if introspectable:
-            obj.introspectable = int(introspectable) > 0
+            try:
+                obj.introspectable = int(introspectable) > 0
+            except ValueError:
+                obj.introspectable = False
         if self._types_only:
             return
         doc = node.find(_corens('doc'))
@@ -195,6 +205,14 @@ class GIRParser(object):
         if stability_doc is not None:
             if stability_doc.text:
                 obj.stability_doc = stability_doc.text
+        attributes = node.findall(_corens('attribute'))
+        if attributes:
+            attributes_ = OrderedDict()
+            for attribute in attributes:
+                name = attribute.attrib.get('name')
+                value = attribute.attrib.get('value')
+                attributes_[name] = value
+            obj.attributes = attributes_
 
     def _parse_object_interface(self, node):
         parent = node.attrib.get('parent')
@@ -471,7 +489,7 @@ class GIRParser(object):
         lenidx = typenode.attrib.get('length')
         if lenidx is not None:
             idx = int(lenidx)
-            assert idx < len(siblings), "%r %d >= %d" % (parent, idx, len(siblings))
+            assert idx < len(siblings), "%r %d >= %d" % (siblings, idx, len(siblings))
             if isinstance(siblings[idx], ast.Field):
                 typeval.length_param_name = siblings[idx].name
             else:
