@@ -1,5 +1,8 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+/* This file gets installed, so we can't assume config.h is available */
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <string.h>
 #include <stdlib.h>
@@ -3435,6 +3438,20 @@ regress_test_callback_user_data (RegressTestCallbackUserData callback,
   return callback(user_data);
 }
 
+/**
+ * regress_test_callback_return_full:
+ * @callback: (scope call):
+ *
+ **/
+void
+regress_test_callback_return_full (RegressTestCallbackReturnFull callback)
+{
+  RegressTestObj *obj;
+
+  obj = callback ();
+  g_object_unref (obj);
+}
+
 static GSList *notified_callbacks = NULL;
 
 /**
@@ -3552,9 +3569,11 @@ regress_test_callback_thaw_async (void)
 void
 regress_test_async_ready_callback (GAsyncReadyCallback callback)
 {
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   GSimpleAsyncResult *result = g_simple_async_result_new (NULL, callback, NULL,
     regress_test_async_ready_callback);
   g_simple_async_result_complete_in_idle (result);
+  G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 /**
