@@ -1041,6 +1041,11 @@ typedef void (*RegressTestCallbackOwnedGError) (GError *error);
  * @path: (type filename): Path to file
  */
 typedef int (*RegressTestCallbackFull) (int foo, double bar, char *path);
+/**
+ * RegressTestCallbackReturnFull:
+ * Return value: (transfer full):
+ */
+typedef RegressTestObj *(*RegressTestCallbackReturnFull) (void);
 /**
  * RegressTestCallbackArray:
  * @one: (array length=one_length):
@@ -1075,6 +1080,9 @@ _GI_TEST_EXTERN
 int regress_test_callback_user_data (RegressTestCallbackUserData callback,
                              gpointer user_data);
 
+_GI_TEST_EXTERN
+void regress_test_callback_return_full (RegressTestCallbackReturnFull callback);
+
 _GI_TEST_EXTERN
 int regress_test_callback_destroy_notify (RegressTestCallbackUserData callback,
                                   gpointer user_data,
